pm4py.algo.discovery.transition\_system package
===============================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.discovery.transition_system.variants

Submodules
----------

pm4py.algo.discovery.transition\_system.algorithm module
--------------------------------------------------------

.. automodule:: pm4py.algo.discovery.transition_system.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.discovery.transition\_system.parameters module
---------------------------------------------------------

.. automodule:: pm4py.algo.discovery.transition_system.parameters
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.transition_system
   :members:
   :undoc-members:
   :show-inheritance:
